@@ -1,9 +1,7 @@
 /*
- * (CAPI*)
- *
  * An implementation of Common ISDN API 2.0 for Asterisk
  *
- * Copyright (C) 2005-2007 Cytronics & Melware
+ * Copyright (C) 2005-2008 Cytronics & Melware
  *
  * Armin Schindler <armin@melware.de>
  * 
@@ -40,13 +38,13 @@
 #include <asterisk/devicestate.h>
 #ifdef CC_AST_HAS_VERSION_1_4
 #include "asterisk/abstract_jb.h"
-#include "asterisk/musiconhold.h"
 #endif
+#include "asterisk/musiconhold.h"
  
 #ifndef _PBX_CAPI_H
 #define _PBX_CAPI_H
 
-#define CAPI_MAX_CONTROLLERS             16
+#define CAPI_MAX_CONTROLLERS             64
 #define CAPI_MAX_B3_BLOCKS                7
 
 /* was : 130 bytes Alaw = 16.25 ms audio not suitable for VoIP */
@@ -92,6 +90,12 @@ static inline unsigned int read_capi_dword(void *m)
 	return (val);
 }
 
+/*
+ * global name for messages and commands
+ */
+#define CC_MESSAGE_NAME "capi"
+#define CC_MESSAGE_BIGNAME "CAPI"
+
 /*
  * define some private functions
  */
@@ -255,6 +259,8 @@ struct cc_capi_gains {
 #define CAPI_WAITEVENT_B3_UP          0x00010000
 #define CAPI_WAITEVENT_B3_DOWN        0x00020000
 #define CAPI_WAITEVENT_ANSWER_FINISH  0x00030000
+#define CAPI_WAITEVENT_HOLD_IND       0x00040000
+#define CAPI_WAITEVENT_ECT_IND        0x00050000
 
 /* Private qsig data for capi device */
 struct cc_qsig_data {
@@ -352,6 +358,8 @@ struct capi_pvt {
 	ast_group_t pickupgroup;
 	ast_group_t group;
 	
+	ast_group_t transfergroup;
+
 	/* language */
 	char language[MAX_LANGUAGE];	
 
@@ -431,6 +439,7 @@ struct capi_pvt {
 	/* deferred tasks */
 	time_t whentohangup;
 	time_t whentoqueuehangup;
+	time_t whentoretrieve;
 
 	/* RTP */
 	struct ast_rtp *rtp;
@@ -494,6 +503,7 @@ struct cc_capi_conf {
 	ast_group_t callgroup;
 	ast_group_t pickupgroup;
 	ast_group_t group;
+	ast_group_t transfergroup;
 	float rxgain;
 	float txgain;
 	struct ast_codec_pref prefs;
@@ -507,6 +517,8 @@ struct cc_capi_conf {
 struct cc_capi_controller {
 	/* which controller is this? */
 	int controller;
+	/* is this controller used? */
+	int used;
 	/* how many bchans? */
 	int nbchannels;
 	/* free bchans */
@@ -597,5 +609,8 @@ extern void capi_wait_for_answered(struct capi_pvt *i);
 extern int capi_wait_for_b3_up(struct capi_pvt *i);
 extern void capi_activehangup(struct capi_pvt *i, int state);
 extern void capi_gains(struct cc_capi_gains *g, float rxgain, float txgain);
+#ifdef CC_AST_HAS_VERSION_1_6
+extern char chatinfo_usage[];
+#endif
 
 #endif
