@@ -1,9 +1,7 @@
 /*
- * (CAPI*)
- *
  * An implementation of Common ISDN API 2.0 for Asterisk
  *
- * Copyright (C) 2005-2007 Cytronics & Melware
+ * Copyright (C) 2005-2008 Cytronics & Melware
  * Copyright (C) 2007 Mario Goegel
  *
  * Armin Schindler <armin@melware.de>
@@ -21,8 +19,6 @@
 #include <stdio.h>
 #include <string.h>
 		
-#include <asterisk/channel.h>
-#include <asterisk/options.h>
 #include "chan_capi20.h"
 #include "chan_capi.h"
 #include "chan_capi_utils.h"
@@ -50,7 +46,7 @@ unsigned int cc_qsig_asn197ade_get_partynumber(char *buf, int buflen, int *idx,
 	
 	numtype = (data[myidx++] & 0x0F);	/* defines type of Number: numDigits, publicPartyNum, nsapEncNum, dataNumDigits */
 	
-	/* cc_verbose(1, 1, VERBOSE_PREFIX_4 " * num type %i,%i\n", numtype, myidx);   */
+	/* cc_qsig_verbose( 1, VERBOSE_PREFIX_4 " * num type %i,%i\n", numtype, myidx);   */
 	switch (numtype){
 		case 0:
 			if (data[myidx] > 0) {	/* length of this context data */
@@ -79,7 +75,7 @@ unsigned int cc_qsig_asn197ade_get_partynumber(char *buf, int buflen, int *idx,
 			}
 			break;
 	};
-	/* cc_verbose(1, 1, VERBOSE_PREFIX_4 " * num type %i,%i\n", numtype, myidx);    */
+	/* cc_qsig_verbose( 1, VERBOSE_PREFIX_4 " * num type %i,%i\n", numtype, myidx);    */
 	return myidx - *idx;
 }
 
@@ -97,7 +93,7 @@ unsigned int cc_qsig_asn197ade_get_numdigits(char *buf, int buflen, int *idx, un
 	memcpy(buf, &data[myidx], strsize);
 	buf[strsize] = 0;
 	
- 	/* cc_verbose(1, 1, VERBOSE_PREFIX_4 " * string length %i,%i\n", strsize, *idx); */
+ 	/* cc_qsig_verbose( 1, VERBOSE_PREFIX_4 " * string length %i,%i\n", strsize, *idx); */
 	return strsize;
 }
 
@@ -138,12 +134,12 @@ unsigned int cc_qsig_asn197ade_get_pns(unsigned char *data, int *idx, struct asn
 	
 	numtype = (data[myidx++] & 0x0F);	/* defines type of Number */
 	
-	/* cc_verbose(1, 1, VERBOSE_PREFIX_4 " * num type %i,%i\n", numtype, myidx);   */
+	/* cc_qsig_verbose( 1, VERBOSE_PREFIX_4 " * num type %i,%i\n", numtype, myidx);   */
 	switch (numtype){
 		case 0:
 			/* myidx points now to length */
 			res = cc_qsig_asn197ade_get_partynumber(buf, buflen, &myidx, data);
-			/* cc_verbose(1, 1, VERBOSE_PREFIX_4 " * res %i\n", numtype);   */
+			/* cc_qsig_verbose( 1, VERBOSE_PREFIX_4 " * res %i\n", numtype);   */
 			if (!res)
 				return 0;
 			
