@@ -1,9 +1,7 @@
 /*
- * (CAPI*)
- *
  * An implementation of Common ISDN API 2.0 for Asterisk
  *
- * Copyright (C) 2006-2007 Cytronics & Melware
+ * Copyright (C) 2006-2008 Cytronics & Melware
  *
  * Armin Schindler <armin@melware.de>
  * 
@@ -131,15 +129,19 @@ void capi_remove_nullif(struct capi_pvt *i)
 /*
  * create new null-interface
  */
-struct capi_pvt *capi_mknullif(struct ast_channel *c, unsigned long controllermask)
+struct capi_pvt *capi_mknullif(struct ast_channel *c, unsigned long long controllermask)
 {
 	struct capi_pvt *tmp;
 	unsigned int controller = 1;
 	int contrcount;
 	int channelcount = 0xffff;
+	int maxcontr = (CAPI_MAX_CONTROLLERS > sizeof(controllermask)) ?
+		sizeof(controllermask) : CAPI_MAX_CONTROLLERS;
 
+	cc_verbose(3, 1, VERBOSE_PREFIX_4 "capi_mknullif: find controller for mask 0x%lx\n",
+		controllermask);
 	/* find the next controller of mask with least plcis used */	
-	for (contrcount = 0; contrcount < CAPI_MAX_CONTROLLERS; contrcount++) {
+	for (contrcount = 0; contrcount < maxcontr; contrcount++) {
 		if ((controllermask & (1 << contrcount))) {
 			if (controller_nullplcis[contrcount] < channelcount) {
 				channelcount = controller_nullplcis[contrcount];
@@ -347,7 +349,7 @@ static MESSAGE_EXCHANGE_ERROR _capi_put_msg(unsigned char *msg)
 	_cmsg CMSG;
 	
 	if (cc_mutex_lock(&capi_put_lock)) {
-		cc_log(LOG_WARNING, "Unable to lock capi put!\n");
+		cc_log(LOG_WARNING, "Unable to lock chan_capi put!\n");
 		return -1;
 	} 
 
@@ -357,7 +359,7 @@ static MESSAGE_EXCHANGE_ERROR _capi_put_msg(unsigned char *msg)
 	error = capi20_put_message(capi_ApplID, msg);
 	
 	if (cc_mutex_unlock(&capi_put_lock)) {
-		cc_log(LOG_WARNING, "Unable to unlock capi put!\n");
+		cc_log(LOG_WARNING, "Unable to unlock chan_capi put!\n");
 		return -1;
 	}
 
@@ -423,9 +425,11 @@ MESSAGE_EXCHANGE_ERROR capi_sendf(
 	capi_prestruct_t *s;
 	unsigned char msg[2048];
 
+	memset(msg, 0, sizeof(msg));
+
 	write_capi_word(&msg[2], capi_ApplID);
-	write_capi_word(&msg[4], ((command >> 8) & 0xff));
-	write_capi_word(&msg[5], (command & 0xff));
+	msg[4] = (unsigned char)((command >> 8) & 0xff);
+	msg[5] = (unsigned char)(command & 0xff);
 	write_capi_word(&msg[6], Number);
 	write_capi_dword(&msg[8], Id);
 
@@ -1023,8 +1027,8 @@ int cc_add_peer_link_id(struct ast_channel *c)
 			/* remove too old entries */
 			if ((peerlinkchannel[a].age + 60) < time(NULL)) {
 				peerlinkchannel[a].channel = NULL;
-				cc_verbose(3, 1, VERBOSE_PREFIX_4 "capi: peerlink %d timeout-erase\n",
-					a);
+				cc_verbose(3, 1, VERBOSE_PREFIX_4 CC_MESSAGE_NAME
+					": peerlink %d timeout-erase\n", a);
 			}
 		}
 	}
@@ -1052,8 +1056,8 @@ struct ast_channel *cc_get_peer_link_id(const char *p)
 		chan = peerlinkchannel[id].channel;
 		peerlinkchannel[id].channel = NULL;
 	}
-	cc_verbose(3, 1, VERBOSE_PREFIX_4 "capi: peerlink %d allocated, peer is %s\n",
-		id, (chan)?chan->name:"unlinked");
+	cc_verbose(3, 1, VERBOSE_PREFIX_4 CC_MESSAGE_NAME
+		": peerlink %d allocated, peer is %s\n", id, (chan)?chan->name:"unlinked");
 	cc_mutex_unlock(&peerlink_lock);
 	return chan;
 }
